Index: /trunk/src/VBox/Devices/Storage/DevAHCI.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DevAHCI.cpp	(revision 76062)
+++ /trunk/src/VBox/Devices/Storage/DevAHCI.cpp	(revision 76063)
@@ -573,4 +573,6 @@
     /** Flag whether the legacy port reset method should be used to make it work with saved states. */
     bool                            fLegacyPortResetMethod;
+    /** Enable tiger (10.4.x) SSTS hack or not. */
+    bool                            fTigerHack;
 
     /** Number of usable ports on this controller. */
@@ -1179,5 +1181,8 @@
         else
         {
-            pAhciPort->regSSTS = 0x1; /* Indicate device presence detected but communication not established. */
+            if (!pAhci->fTigerHack)
+                pAhciPort->regSSTS = 0x1;   /* Indicate device presence detected but communication not established. */
+            else
+                pAhciPort->regSSTS = 0x0;   /* Indicate no device detected after COMRESET. [tiger hack] */
             pAhciPort->regSCTL = u32Value;  /* Update before kicking the I/O thread. */
 
@@ -5882,5 +5887,6 @@
                                     "PortCount\0"
                                     "Bootable\0"
-                                    "CmdSlotsAvail\0"))
+                                    "CmdSlotsAvail\0"
+                                    "TigerHack\0"))
         return PDMDEV_SET_ERROR(pDevIns, VERR_PDM_DEVINS_UNKNOWN_CFG_VALUES,
                                 N_("AHCI configuration error: unknown option specified"));
@@ -5930,4 +5936,8 @@
                                    N_("AHCI configuration error: CmdSlotsAvail=%u should be at least 1"),
                                    pThis->cCmdSlotsAvail);
+    bool fTigerHack;
+    rc = CFGMR3QueryBoolDef(pCfg, "TigerHack", &fTigerHack, false);
+    if (RT_FAILURE(rc))
+        return PDMDEV_SET_ERROR(pDevIns, rc, N_("AHCI configuration error: failed to read TigerHack as boolean"));
 
     /*
